@@ -6,14 +6,16 @@ import urllib
 from contextlib import suppress
 from dataclasses import dataclass
 from datetime import datetime, timedelta
-from typing import Dict, Optional
+from typing import Dict, Optional, Any, List
 from urllib import parse
 from urllib.parse import quote
 
+import aiohttp
 from aiohttp import ClientResponse
 from yarl import URL
 
 from pyhon import const, exceptions
+from pyhon.connection.device import HonDevice
 from pyhon.connection.handler.auth import HonAuthConnectionHandler
 
 _LOGGER = logging.getLogger(__name__)
@@ -25,41 +27,52 @@ class HonLoginData:
     email: str = ""
     password: str = ""
     fw_uid: str = ""
-    loaded: Optional[Dict] = None
+    loaded: Optional[Dict[str, Any]] = None
+
+
+@dataclass
+class HonAuthData:
+    access_token: str = ""
+    refresh_token: str = ""
+    cognito_token: str = ""
+    id_token: str = ""
 
 
 class HonAuth:
     _TOKEN_EXPIRES_AFTER_HOURS = 8
     _TOKEN_EXPIRE_WARNING_HOURS = 7
 
-    def __init__(self, session, email, password, device) -> None:
+    def __init__(
+        self,
+        session: aiohttp.ClientSession,
+        email: str,
+        password: str,
+        device: HonDevice,
+    ) -> None:
         self._session = session
         self._request = HonAuthConnectionHandler(session)
         self._login_data = HonLoginData()
         self._login_data.email = email
         self._login_data.password = password
-        self._access_token = ""
-        self._refresh_token = ""
-        self._cognito_token = ""
-        self._id_token = ""
         self._device = device
         self._expires: datetime = datetime.utcnow()
+        self._auth = HonAuthData()
 
     @property
     def cognito_token(self) -> str:
-        return self._cognito_token
+        return self._auth.cognito_token
 
     @property
     def id_token(self) -> str:
-        return self._id_token
+        return self._auth.id_token
 
     @property
     def access_token(self) -> str:
-        return self._access_token
+        return self._auth.access_token
 
     @property
     def refresh_token(self) -> str:
-        return self._refresh_token
+        return self._auth.refresh_token
 
     def _check_token_expiration(self, hours: int) -> bool:
         return datetime.utcnow() >= self._expires + timedelta(hours=hours)
@@ -107,7 +120,8 @@ class HonAuth:
         async with self._request.get(url) as response:
             text = await response.text()
             self._expires = datetime.utcnow()
-            if not (login_url := re.findall("url = '(.+?)'", text)):
+            login_url: List[str] = re.findall("url = '(.+?)'", text)
+            if not login_url:
                 if "oauth/done#access_token=" in text:
                     self._parse_token_data(text)
                     raise exceptions.HonNoAuthenticationNeeded()
@@ -120,7 +134,7 @@ class HonAuth:
                 await self._error_logger(response)
         return new_location
 
-    async def _handle_redirects(self, login_url) -> str:
+    async def _handle_redirects(self, login_url: str) -> str:
         redirect1 = await self._manual_redirect(login_url)
         redirect2 = await self._manual_redirect(redirect1)
         return f"{redirect2}&System=IoT_Mobile_App&RegistrationSubChannel=hOn"
@@ -176,18 +190,19 @@ class HonAuth:
             if response.status == 200:
                 with suppress(json.JSONDecodeError, KeyError):
                     result = await response.json()
-                    return result["events"][0]["attributes"]["values"]["url"]
+                    url: str = result["events"][0]["attributes"]["values"]["url"]
+                    return url
             await self._error_logger(response)
             return ""
 
     def _parse_token_data(self, text: str) -> bool:
         if access_token := re.findall("access_token=(.*?)&", text):
-            self._access_token = access_token[0]
+            self._auth.access_token = access_token[0]
         if refresh_token := re.findall("refresh_token=(.*?)&", text):
-            self._refresh_token = refresh_token[0]
+            self._auth.refresh_token = parse.unquote(refresh_token[0])
         if id_token := re.findall("id_token=(.*?)&", text):
-            self._id_token = id_token[0]
-        return True if access_token and refresh_token and id_token else False
+            self._auth.id_token = id_token[0]
+        return bool(access_token and refresh_token and id_token)
 
     async def _get_token(self, url: str) -> bool:
         async with self._request.get(url) as response:
@@ -219,7 +234,7 @@ class HonAuth:
         return True
 
     async def _api_auth(self) -> bool:
-        post_headers = {"id-token": self._id_token}
+        post_headers = {"id-token": self._auth.id_token}
         data = self._device.get()
         async with self._request.post(
             f"{const.API_URL}/auth/v1/login", headers=post_headers, json=data
@@ -229,8 +244,8 @@ class HonAuth:
             except json.JSONDecodeError:
                 await self._error_logger(response)
                 return False
-            self._cognito_token = json_data.get("cognitoUser", {}).get("Token", "")
-            if not self._cognito_token:
+            self._auth.cognito_token = json_data.get("cognitoUser", {}).get("Token", "")
+            if not self._auth.cognito_token:
                 _LOGGER.error(json_data)
                 raise exceptions.HonAuthenticationError()
         return True
@@ -249,10 +264,12 @@ class HonAuth:
         except exceptions.HonNoAuthenticationNeeded:
             return
 
-    async def refresh(self) -> bool:
+    async def refresh(self, refresh_token: str = "") -> bool:
+        if refresh_token:
+            self._auth.refresh_token = refresh_token
         params = {
             "client_id": const.CLIENT_ID,
-            "refresh_token": self._refresh_token,
+            "refresh_token": self._auth.refresh_token,
             "grant_type": "refresh_token",
         }
         async with self._request.post(
@@ -263,14 +280,14 @@ class HonAuth:
                 return False
             data = await response.json()
         self._expires = datetime.utcnow()
-        self._id_token = data["id_token"]
-        self._access_token = data["access_token"]
+        self._auth.id_token = data["id_token"]
+        self._auth.access_token = data["access_token"]
         return await self._api_auth()
 
     def clear(self) -> None:
         self._session.cookie_jar.clear_domain(const.AUTH_API.split("/")[-2])
         self._request.called_urls = []
-        self._cognito_token = ""
-        self._id_token = ""
-        self._access_token = ""
-        self._refresh_token = ""
+        self._auth.cognito_token = ""
+        self._auth.id_token = ""
+        self._auth.access_token = ""
+        self._auth.refresh_token = ""
