@@ -1,13 +1,16 @@
 AUTH_API = "https://account2.hon-smarthome.com"
 API_URL = "https://api-iot.he.services"
 API_KEY = "GRCqFhC6Gk@ikWXm1RmnSmX1cm,MxY-configuration"
+AWS_ENDPOINT = "a30f6tqw0oh1x0-ats.iot.eu-west-1.amazonaws.com"
+AWS_AUTHORIZER = "candy-iot-authorizer"
 APP = "hon"
 CLIENT_ID = (
     "3MVG9QDx8IX8nP5T2Ha8ofvlmjLZl5L_gvfbT9."
     "HJvpHGKoAS_dcMN8LYpTSYeVFCraUnV.2Ag1Ki7m4znVO6"
 )
-APP_VERSION = "2.3.5"
-OS_VERSION = 31
+APP_VERSION = "2.6.5"
+OS_VERSION = 999
 OS = "android"
-DEVICE_MODEL = "exynos9820"
-USER_AGENT = "Chrome/110.0.5481.153"
+DEVICE_MODEL = "pyhOn"
+USER_AGENT = "Chrome/999.999.999.999"
+MOBILE_ID = "pyhOn"
